import ttkbootstrap as tb
from ttkbootstrap.constants import *
from tkinter import messagebox
import requests

# Backend API URL
API_URL = "http://127.0.0.1:8000"

# Function to handle registration
def register():
    username = entry_username.get()
    email = entry_email.get()
    phone_number = entry_phone.get()
    password = entry_password.get()
    confirm_password = entry_confirm_password.get()

    if not username or not email or not password or not confirm_password:
        messagebox.showwarning("Input Error", "All fields are required!")
        return

    if password != confirm_password:
        messagebox.showerror("Password Error", "Passwords do not match!")
        return

    # Send registration data to backend
    response = requests.post(f"{API_URL}/auth/signup", json={
        "username": username,
        "email": email,
        "phone_number": phone_number,
        "password": password
    })

    try:
        response_data = response.json()
        if response.status_code == 200:
            messagebox.showinfo("Registration Successful", f"Welcome, {username}!")
        else:
            messagebox.showerror("Registration Failed", response_data.get("detail", "Unknown error"))
    except requests.exceptions.JSONDecodeError:
        messagebox.showerror("Registration Failed", f"Server returned non-JSON response: {response.text}")

# Function to handle login
def login():
    email = entry_email.get()
    password = entry_password.get()

    # Send login data to backend
    response = requests.post(f"{API_URL}/auth/login", json={
        "email": email,
        "password": password
    })

    if response.status_code == 200:
        messagebox.showinfo("Login Successful", "Welcome!")
    else:
        messagebox.showerror("Login Failed", response.json().get("detail", "Invalid credentials"))

# Create main window
root = tb.Window(themename="superhero")  # Change to "darkly", "superhero", etc.
root.title("Shopping App")
root.geometry("900x800")

# Title Label
label_title = tb.Label(root, text="Shopping App", font=("Helvetica", 18, "bold"))
label_title.pack(pady=10)

# Username Entry
tb.Label(root, text="Username:").pack(pady=5)
entry_username = tb.Entry(root, bootstyle="info")
entry_username.pack(pady=5)

# Email Entry
tb.Label(root, text="Email:").pack(pady=5)
entry_email = tb.Entry(root, bootstyle="info")
entry_email.pack(pady=5)

# Phone Entry
tb.Label(root, text="Phone Number:").pack(pady=5)
entry_phone = tb.Entry(root, bootstyle="info")
entry_phone.pack(pady=5)

# Password Entry
tb.Label(root, text="Password:").pack(pady=5)
entry_password = tb.Entry(root, bootstyle="info", show="*")
entry_password.pack(pady=5)

# Confirm Password Entry
tb.Label(root, text="Confirm Password:").pack(pady=5)
entry_confirm_password = tb.Entry(root, bootstyle="info", show="*")
entry_confirm_password.pack(pady=5)

# Register Button
btn_register = tb.Button(root, text="Register", bootstyle="success", command=register)
btn_register.pack(pady=15)

# Login Button
btn_login = tb.Button(root, text="Login", bootstyle="primary", command=login)
btn_login.pack(pady=15)

# Run the GUI
root.mainloop()